@@ -1,7 +1,6 @@
 from tornado.httpserver import HTTPServer
 import tornado.web
 import logging
-import asyncio
 
 log = logging.getLogger("whirlwind.server")
 
@@ -25,7 +24,7 @@ class Server(object):
 
         http_server.listen(port, host)
         try:
-            await self.final_future
+            await self.wait_for_end()
         except ForcedQuit:
             log.info("The server was told to shut down")
         finally:
@@ -34,6 +33,10 @@ class Server(object):
             finally:
                 await self.cleanup()
 
+    async def wait_for_end(self):
+        """Hook that will end when we need to stop the server"""
+        await self.final_future
+
     async def setup(self, *args, **kwargs):
         """
         Hook that receives all extra args and kwargs from serve
@@ -50,14 +53,3 @@ class Server(object):
 
     async def cleanup(self):
         """Called after the server has stopped"""
-
-
-async def wait_for_futures(futures):
-    """
-    Helper for waiting on futures in a dictionary of {key: future}
-
-    Useful for waiting on the wsconnections object given to a WSHandler
-    """
-    ts = list(futures.values())
-    if ts:
-        await asyncio.wait(ts)
